@@ -78,6 +78,7 @@
 */
 #include <pbs_config.h>   /* the master config generated by configure */
 
+#include <ctype.h>
 #include <stdio.h>
 #include <sys/types.h>
 #include <netdb.h>
@@ -143,11 +144,47 @@ pbs_net_t get_hostaddr(
 
   extern int pbs_errno;
 
+#ifdef NUMA_SUPPORT
+  /* if this is a numa host, just get the parent node's address */
+  char *dash;
+
+  if ((dash = strchr(hostname,'-')) != NULL)
+    {
+    char *tmp;
+
+    /* make sure to use the last dash */
+    while ((tmp = strchr(dash+1,'-')))
+      dash = tmp;
+
+    if (isdigit(*(dash+1)))
+      {
+      /* terminate string temporarily */
+      *dash = '\0';
+
+      /* check if this resolves to a hostname without the dash */
+      if (!(hp = gethostbyname(hostname)))
+        {
+        /* not a numa-owned node, act normal */
+        *dash = '-';
+        hp = gethostbyname(hostname);
+        }
+      }
+    /* otherwise proceed with just the parent hostname so 
+     * it can be resolved */
+    else
+      hp = gethostbyname(hostname);
+    }
+  else
+    hp = gethostbyname(hostname);
+#else
   hp = gethostbyname(hostname);
+#endif /* NUMA_SUPPORT */
+
 
   if (hp == NULL)
     {
-    sprintf(log_buffer,"cannot resolve IP address for host '%s' herror=%d: %s",
+    snprintf(log_buffer, sizeof(log_buffer),
+      "cannot resolve IP address for host '%s' herror=%d: %s",
       hostname,
       h_errno,
       hstrerror(h_errno));
