@@ -249,7 +249,37 @@ void remove_defunct_cpusets()
   } /* END remove_defunct_cpusets() */
 
 
+int get_cpuset_size(char *cpusetStr)
+  {
+  int val1 = -1;
+  int val2 = -2;
+  int j;
+  int range = FALSE;
+  int len = 0;
+  char *ptr;
 
+  val1 = atoi(cpusetStr);
+  range = TRUE;
+
+  len = strlen(cpusetStr);
+  for (j=0; j<len; j++)
+    {
+    if (cpusetStr[j] == '-')
+      {
+      range = TRUE;
+      ptr = cpusetStr;
+      ptr += j + 1;
+      val2 = atoi(ptr);
+      break;
+      }
+    }
+  
+  if (val2 != -1)
+    return(val2+1);
+  else
+    return(val1);
+  
+  }
 
 
 /**
@@ -258,7 +288,6 @@ void remove_defunct_cpusets()
  *
  * @param cpusetStr - (I) the cpuset string
  * @param cpusetMap - (I/O) the cpuset map
- * @param mapSize - (I) the map size
  * @param add - (I) True to add cpuset to map else we remove cpuset from map
  */
 
@@ -266,7 +295,6 @@ void adjust_root_map(
 
   char *cpusetStr, /* I */
   int   cpusetMap[], /* I/O */
-  int   mapSize,   /* I */
   int   add)       /* I */
 
   {
@@ -347,19 +375,26 @@ void remove_boot_set(
   static char    id[] = "remove_boot_set";
   int   j;
   int   first;
-  int   cpusetMap[1024];
+  int   *cpusetMap;
+  int   cpuset_size;
   char  tmpBuf[MAXPATHLEN];
 
   if ((rootStr == NULL) ||
       (bootStr == NULL))
     return;
   
-  /* clear out map */
-  for (j=0; j<1024; j++)
+
+  cpuset_size = get_cpuset_size(rootStr);
+  if (cpuset_size <= 0)
     {
-    cpusetMap[j] = 0;
+    return;
     }
 
+  cpusetMap = (int *)calloc(1, cpuset_size + 1);
+  if(cpusetMap == NULL)
+    return;
+
+
   if (LOGLEVEL >= 7)
     {
     sprintf(log_buffer,
@@ -369,16 +404,16 @@ void remove_boot_set(
     }
 
   /* add the root cpuset to the map */
-  adjust_root_map(rootStr, cpusetMap, 1024, TRUE);
+  adjust_root_map(rootStr, cpusetMap, TRUE);
 
   /* now remove the boot cpuset from the map */
-  adjust_root_map(bootStr, cpusetMap, 1024, FALSE);
+  adjust_root_map(bootStr, cpusetMap, FALSE);
   
   /* convert the cpuset map back into the root cpuset string */
 
   rootStr[0] = '\0';
   first = TRUE;
-  for (j=0; j<1024; j++)
+  for (j=0; j<cpuset_size; j++)
     {
     if (cpusetMap[j] > 0 )
       {
@@ -404,6 +439,7 @@ void remove_boot_set(
     }
 
 
+  free(cpusetMap);
   return;
   }
 
@@ -689,12 +725,6 @@ initialize_root_cpuset(void)
       memset(cpuset_buf, '\0', sizeof(cpuset_buf));
       }  /* END if (fp != NULL) */
     }    /* END if (lstat(path,&statbuf) != 0) */
-  else
-    {
-    /* The cpuset already exists, delete any cpusets for jobs that no longer exist. */
-
-    remove_defunct_cpusets();
-    }
 
   return;
   }  /* END initialize_root_cpuset() */
@@ -882,6 +912,7 @@ int get_cpuset_strings(
   int     ratio = 0;
   char    tmpStr[MAXPATHLEN];
   int     numa_index;
+  char    *mem_idx_str;
 
 #ifdef NUMA_SUPPORT
   numanode *numa_tmp;
@@ -943,13 +974,34 @@ int get_cpuset_strings(
 #ifdef NUMA_SUPPORT
     sprintf(tmpStr,"%d",mem_index);
 
-    if (strstr(MemStr,tmpStr) == NULL)
+    mem_idx_str = strstr(MemStr, tmpStr);
+    if (mem_idx_str == NULL)
       {
+      /* This mem_index is not in the MemStr. 
+         add it. */
       if (MemStr[0] != '\0')
         strcat(MemStr, ",");
 
       strcat(MemStr, tmpStr);
       }
+    else
+      {
+      /* Just because strstr returned a value
+         does not mean the substring matched
+         a whole index value. Check it */
+      if ((((mem_idx_str[strlen(tmpStr)]) != ',') && (mem_idx_str[strlen(tmpStr)] != '\0'))
+           || ((mem_idx_str != MemStr) && (*(mem_idx_str - 1) != ',')))
+        {
+        /* The end of the sub-string is good, now check the front */
+          {
+          if (MemStr[0] != '\0')
+            strcat(MemStr, ",");
+
+          strcat(MemStr, tmpStr);
+          }
+
+        }
+      }
 #endif
     }
 
