@@ -285,6 +285,7 @@ char           *NodeSuffix = NULL;
 int MultiMomMode = 0;
 
 int allow_any_mom = FALSE;
+int array_259_upgrade = FALSE;
 
 void DIS_rpp_reset(void)
 
@@ -606,7 +607,7 @@ void parse_command_line(int argc, char *argv[])
 
 
 
-  while ((c = getopt(argc, argv, "A:a:d:DefhH:L:l:mM:p:R:S:t:v-:")) != -1)
+  while ((c = getopt(argc, argv, "A:a:d:DefhH:L:l:mM:p:R:S:t:uv-:")) != -1)
     {
     switch (c)
       {
@@ -929,6 +930,10 @@ void parse_command_line(int argc, char *argv[])
 
         break;
 
+      case 'u':
+        array_259_upgrade = TRUE;
+        break;
+
       case 'v':
 
         fprintf(stderr, "version: %s\n",
