@@ -133,6 +133,9 @@ extern char *PJobState[];
 extern void cleanup_restart_file(job *);
 extern void rel_resc(job *);
 
+extern job  *chk_job_request(char *, struct batch_request *);
+extern struct batch_request *cpy_checkpoint(struct batch_request *, job *, enum job_atr, int);
+
 /* prototypes */
 void post_modify_arrayreq(struct work_task *pwt);
 static void post_modify_req(struct work_task *pwt);
@@ -254,7 +257,7 @@ void mom_cleanup_checkpoint_hold(
       {
       strcpy(preq->rq_ind.rq_delete.rq_objname, pjob->ji_qs.ji_jobid);
 
-      if ((rc = relay_to_mom(pjob->ji_qs.ji_un.ji_exect.ji_momaddr, preq, release_req)) != 0)
+      if ((rc = relay_to_mom(pjob, preq, release_req)) != 0)
         {
         snprintf(log_buffer,sizeof(log_buffer),
           "Unable to relay information to mom for job '%s'\n",
@@ -417,13 +420,15 @@ int modify_job(
       sprintf(log_buffer,"setting jobsubstate for %s to RERUN\n", pjob->ji_qs.ji_jobid);
 
       pjob->ji_qs.ji_substate = JOB_SUBSTATE_RERUN;
-      job_save(pjob, SAVEJOB_QUICK);
+
+      job_save(pjob, SAVEJOB_QUICK, 0);
+
       LOG_EVENT(PBSEVENT_JOB, PBS_EVENTCLASS_JOB,
                 pjob->ji_qs.ji_jobid, log_buffer);
 
       /* remove checkpoint restart file if there is one */
       
-      if (pjob->ji_wattr[(int)JOB_ATR_restart_name].at_flags & ATR_VFLAG_SET)
+      if (pjob->ji_wattr[JOB_ATR_restart_name].at_flags & ATR_VFLAG_SET)
         {
         cleanup_restart_file(pjob);
         }
@@ -469,7 +474,7 @@ int modify_job(
 
       /* NOTE:  only explicitly specified job attributes are routed down to MOM */
 
-      if (i == (int)JOB_ATR_resource)
+      if (i == JOB_ATR_resource)
         {
         /* is the specified resource modifiable while */
         /* the job is running                         */
@@ -504,7 +509,7 @@ int modify_job(
         sendmom = 1;
         }
 /*
-        else if ((i == (int)JOB_ATR_checkpoint_name) || (i == (int)JOB_ATR_variables))
+        else if ((i == JOB_ATR_checkpoint_name) || (i == JOB_ATR_variables))
         {
         sendmom = 1;
         }
@@ -547,7 +552,7 @@ int modify_job(
     }
   else
     {
-    job_save(pjob, SAVEJOB_FULL);
+    job_save(pjob, SAVEJOB_FULL, 0);
     }
 
   sprintf(log_buffer, msg_manager,
@@ -568,10 +573,10 @@ int modify_job(
     {
     /* if the NO_MOM_RELAY flag is set the calling function will call
        relay_to_mom so we do not need to do it here */
-    if(flag != NO_MOM_RELAY)
+    if (flag != NO_MOM_RELAY)
       {
       if ((rc = relay_to_mom(
-                  pjob->ji_qs.ji_un.ji_exect.ji_momaddr,
+                  pjob,
                   preq,
                   post_modify_req)))
         {  
@@ -600,11 +605,11 @@ int modify_job(
 
       if (checkpoint_req == CHK_HOLD)
         {
-        rc = relay_to_mom(pjob->ji_qs.ji_un.ji_exect.ji_momaddr, momreq, chkpt_xfr_hold);
+        rc = relay_to_mom(pjob, momreq, chkpt_xfr_hold);
         }
       else
         {
-        rc = relay_to_mom(pjob->ji_qs.ji_un.ji_exect.ji_momaddr, momreq, chkpt_xfr_done);
+        rc = relay_to_mom(pjob, momreq, chkpt_xfr_done);
         }
       if (rc != 0)
         {
@@ -636,7 +641,7 @@ int copy_batchrequest(struct batch_request **newreq, struct batch_request *preq,
     char newjobname[PBS_MAXSVRJOBID+1];
 
     request = alloc_br(type);
-    if(request)
+    if (request)
       {
       request->rq_type = preq->rq_type;
       request->rq_perm = preq->rq_perm;
@@ -650,10 +655,10 @@ int copy_batchrequest(struct batch_request **newreq, struct batch_request *preq,
       request->rq_reply.brp_choice = preq->rq_reply.brp_choice;
       request->rq_noreply = preq->rq_noreply;
       /* we need to copy rq_extend if there is any data */
-      if(preq->rq_extend)
+      if (preq->rq_extend)
         {
         request->rq_extend = (char *)malloc(strlen(preq->rq_extend) + 1);
-        if(request->rq_extend == NULL)
+        if (request->rq_extend == NULL)
           {
           return(PBSE_SYSTEM);
           }
@@ -687,7 +692,7 @@ int copy_batchrequest(struct batch_request **newreq, struct batch_request *preq,
              and not the individual job. We need to find out what we have and
              modify the name if needed */
           ptr1 = strstr(preq->rq_ind.rq_manager.rq_objname, "[]");
-          if(ptr1)
+          if (ptr1)
             {
             ptr1++;
             strcpy(newjobname, preq->rq_ind.rq_manager.rq_objname);
@@ -707,7 +712,7 @@ int copy_batchrequest(struct batch_request **newreq, struct batch_request *preq,
           while(pal != NULL)
             {
             newpal = (svrattrl *)malloc(pal->al_tsize + 1);
-            if(!newpal)
+            if (!newpal)
               {
               return(PBSE_SYSTEM);
               }
@@ -777,25 +782,25 @@ int modify_whole_array(
     /* NO_MOM_RELAY will prevent modify_job from calling relay_to_mom */
     rc = modify_job(pa->jobs[i],plist,preq,checkpoint_req, NO_MOM_RELAY);
 
-    if(rc == PBSE_RELAYED_TO_MOM)
+    if (rc == PBSE_RELAYED_TO_MOM)
       {
       struct batch_request *array_req = NULL;
 
       /* We told modify_job not to call relay_to_mom so we need to contact the mom */
       rc = copy_batchrequest(&array_req, preq, 0, i);
-      if(rc != 0)
+      if (rc != 0)
         {
         return(rc);
         }
 
       preq->rq_refcount++;
-      if(mom_relay == 0)
+      if (mom_relay == 0)
         {
         preq->rq_refcount++;
         }
       mom_relay++;
       if ((rc = relay_to_mom(
-                  pa->jobs[i]->ji_qs.ji_un.ji_exect.ji_momaddr,
+                  pa->jobs[i],
                   array_req,
                   post_modify_arrayreq)))
         {  
@@ -810,10 +815,10 @@ int modify_whole_array(
       }
     }
 
-  if(mom_relay)
+  if (mom_relay)
     {
     preq->rq_refcount--;
-    if(preq->rq_refcount == 0)
+    if (preq->rq_refcount == 0)
       {
       free_br(preq);
       }
@@ -904,7 +909,7 @@ void req_modifyarray(
     /* there is more than just a slot given, modify that range */
     rc = modify_array_range(pa,array_spec,plist,preq,checkpoint_req);
 
-    if((rc != 0) && 
+    if ((rc != 0) && 
        (rc != PBSE_RELAYED_TO_MOM))
       {
       req_reject(PBSE_IVALREQ,0,preq,NULL,"Error reading array range");
@@ -915,7 +920,7 @@ void req_modifyarray(
     if (pcnt != NULL)
       *pcnt = '%';
 
-    if(rc == PBSE_RELAYED_TO_MOM)
+    if (rc == PBSE_RELAYED_TO_MOM)
       {
       return;
       }
@@ -947,7 +952,7 @@ void req_modifyarray(
       return;
       }
 
-    if(rc == PBSE_RELAYED_TO_MOM)
+    if (rc == PBSE_RELAYED_TO_MOM)
       {
       return;
       }
@@ -1029,7 +1034,7 @@ void req_modifyjob(
     if ((rc == PBSE_MODATRRUN) ||
         (rc == PBSE_UNKRESC))
       reply_badattr(rc,1,plist,preq);
-    else if( rc == PBSE_RELAYED_TO_MOM )
+    else if ( rc == PBSE_RELAYED_TO_MOM )
       {
       return;
       }
@@ -1062,14 +1067,14 @@ int modify_job_attr(
   {
   int      allow_unkn;
   long      i;
-  attribute  newattr[(int)JOB_ATR_LAST];
+  attribute  newattr[JOB_ATR_LAST];
   attribute *pattr;
   int      rc;
 
   if (pjob->ji_qhdr->qu_qs.qu_type == QTYPE_Execution)
     allow_unkn = -1;
   else
-    allow_unkn = (int)JOB_ATR_UNKN;
+    allow_unkn = JOB_ATR_UNKN;
 
   pattr = pjob->ji_wattr;
 
@@ -1088,7 +1093,7 @@ int modify_job_attr(
   /* if resource limits are being changed ... */
 
   if ((rc == 0) &&
-      (newattr[(int)JOB_ATR_resource].at_flags & ATR_VFLAG_SET))
+      (newattr[JOB_ATR_resource].at_flags & ATR_VFLAG_SET))
     {
     if ((perm & (ATR_DFLAG_MGWR | ATR_DFLAG_OPWR)) == 0)
       {
@@ -1097,9 +1102,9 @@ int modify_job_attr(
       if (pjob->ji_qs.ji_state == JOB_STATE_RUNNING)
         {
         if ((comp_resc2(
-               &pjob->ji_wattr[(int)JOB_ATR_resource],
-               &newattr[(int)JOB_ATR_resource],
-               server.sv_attr[(int)SRV_ATR_QCQLimits].at_val.at_long,
+               &pjob->ji_wattr[JOB_ATR_resource],
+               &newattr[JOB_ATR_resource],
+               server.sv_attr[SRV_ATR_QCQLimits].at_val.at_long,
                NULL) == -1) ||
             (comp_resc_lt != 0))
           {
@@ -1112,7 +1117,7 @@ int modify_job_attr(
       if (rc == 0)
         {
         rc = chk_resc_limits(
-               &newattr[(int)JOB_ATR_resource],
+               &newattr[JOB_ATR_resource],
                pjob->ji_qhdr,
                NULL);
         }
@@ -1122,10 +1127,10 @@ int modify_job_attr(
   /* special check on permissions for hold */
 
   if ((rc == 0) &&
-      (newattr[(int)JOB_ATR_hold].at_flags & ATR_VFLAG_MODIFY))
+      (newattr[JOB_ATR_hold].at_flags & ATR_VFLAG_MODIFY))
     {
-    i = newattr[(int)JOB_ATR_hold].at_val.at_long ^
-        (pattr + (int)JOB_ATR_hold)->at_val.at_long;
+    i = newattr[JOB_ATR_hold].at_val.at_long ^
+        (pattr + JOB_ATR_hold)->at_val.at_long;
 
     rc = chk_hold_priv(i, perm);
     }
@@ -1150,8 +1155,8 @@ int modify_job_attr(
       }    /* END for (i) */
 
     if ((rc == 0) &&
-        ((newattr[(int)JOB_ATR_userlst].at_flags & ATR_VFLAG_MODIFY) ||
-         (newattr[(int)JOB_ATR_grouplst].at_flags & ATR_VFLAG_MODIFY)))
+        ((newattr[JOB_ATR_userlst].at_flags & ATR_VFLAG_MODIFY) ||
+         (newattr[JOB_ATR_grouplst].at_flags & ATR_VFLAG_MODIFY)))
       {
       /* need to reset execution uid and gid */
 
@@ -1159,51 +1164,51 @@ int modify_job_attr(
       }
 
     if ((rc == 0) &&
-        (newattr[(int)JOB_ATR_outpath].at_flags & ATR_VFLAG_MODIFY))
+        (newattr[JOB_ATR_outpath].at_flags & ATR_VFLAG_MODIFY))
       {
       /* need to recheck if JOB_ATR_outpath is a special case of host only */
 
-      if (newattr[(int)JOB_ATR_outpath].at_val.at_str[strlen(newattr[(int)JOB_ATR_outpath].at_val.at_str) - 1] == ':')
+      if (newattr[JOB_ATR_outpath].at_val.at_str[strlen(newattr[JOB_ATR_outpath].at_val.at_str) - 1] == ':')
         {
-        newattr[(int)JOB_ATR_outpath].at_val.at_str =
+        newattr[JOB_ATR_outpath].at_val.at_str =
           prefix_std_file(pjob, (int)'o');
         }
       /*
        * if the output path was specified and ends with a '/'
        * then append the standard file name
        */
-      else if (newattr[(int)JOB_ATR_outpath].at_val.at_str[strlen(newattr[(int)JOB_ATR_outpath].at_val.at_str) - 1] == '/')
+      else if (newattr[JOB_ATR_outpath].at_val.at_str[strlen(newattr[JOB_ATR_outpath].at_val.at_str) - 1] == '/')
         {
-          newattr[(int)JOB_ATR_outpath].at_val.at_str[strlen(newattr[(int)JOB_ATR_outpath].at_val.at_str) - 1] = '\0';
+          newattr[JOB_ATR_outpath].at_val.at_str[strlen(newattr[JOB_ATR_outpath].at_val.at_str) - 1] = '\0';
           
-          replace_attr_string(&newattr[(int)JOB_ATR_outpath],
+          replace_attr_string(&newattr[JOB_ATR_outpath],
                             (add_std_filename(pjob,
-                            newattr[(int)JOB_ATR_outpath].at_val.at_str,
+                            newattr[JOB_ATR_outpath].at_val.at_str,
                             (int)'o')));
         }
       }
 
     if ((rc == 0) &&
-        (newattr[(int)JOB_ATR_errpath].at_flags & ATR_VFLAG_MODIFY))
+        (newattr[JOB_ATR_errpath].at_flags & ATR_VFLAG_MODIFY))
       {
       /* need to recheck if JOB_ATR_errpath is a special case of host only */
 
-      if (newattr[(int)JOB_ATR_errpath].at_val.at_str[strlen(newattr[(int)JOB_ATR_errpath].at_val.at_str) - 1] == ':')
+      if (newattr[JOB_ATR_errpath].at_val.at_str[strlen(newattr[JOB_ATR_errpath].at_val.at_str) - 1] == ':')
         {
-        newattr[(int)JOB_ATR_errpath].at_val.at_str =
+        newattr[JOB_ATR_errpath].at_val.at_str =
           prefix_std_file(pjob, (int)'e');
         }
       /*
        * if the error path was specified and ends with a '/'
        * then append the standard file name
        */
-      else if (newattr[(int)JOB_ATR_errpath].at_val.at_str[strlen(newattr[(int)JOB_ATR_errpath].at_val.at_str) - 1] == '/')
+      else if (newattr[JOB_ATR_errpath].at_val.at_str[strlen(newattr[JOB_ATR_errpath].at_val.at_str) - 1] == '/')
         {
-          newattr[(int)JOB_ATR_errpath].at_val.at_str[strlen(newattr[(int)JOB_ATR_errpath].at_val.at_str) - 1] = '\0';
+          newattr[JOB_ATR_errpath].at_val.at_str[strlen(newattr[JOB_ATR_errpath].at_val.at_str) - 1] = '\0';
           
-          replace_attr_string(&newattr[(int)JOB_ATR_errpath],
+          replace_attr_string(&newattr[JOB_ATR_errpath],
                             (add_std_filename(pjob,
-                            newattr[(int)JOB_ATR_errpath].at_val.at_str,
+                            newattr[JOB_ATR_errpath].at_val.at_str,
                             (int)'e')));
         }
       }
@@ -1293,7 +1298,7 @@ void post_modify_arrayreq(
       log_buffer);
 
     parent_req->rq_refcount--;
-    if(parent_req->rq_refcount == 0)
+    if (parent_req->rq_refcount == 0)
       {
       free_br(preq);
       req_reject(parent_req->rq_reply.brp_code, 0, parent_req, NULL, NULL);
@@ -1308,7 +1313,7 @@ void post_modify_arrayreq(
       if ((pjob = find_job(preq->rq_ind.rq_modify.rq_objname)) == NULL)
         {
         parent_req->rq_refcount--;
-        if(parent_req->rq_refcount == 0)
+        if (parent_req->rq_refcount == 0)
           {
           free_br(preq);
           req_reject(parent_req->rq_reply.brp_code, 0, parent_req, NULL, NULL);
@@ -1340,7 +1345,7 @@ void post_modify_arrayreq(
       }
 
     parent_req->rq_refcount--;
-    if(parent_req->rq_refcount == 0)
+    if (parent_req->rq_refcount == 0)
       {
       parent_req->rq_reply.brp_code = preq->rq_reply.brp_code;
       free_br(preq);
