@@ -151,7 +151,7 @@ extern int   LOGLEVEL;
 extern char *PJobState[];
 
 
-
+extern int   svr_chk_owner(struct batch_request *, job *);
 
 
 /*
@@ -201,7 +201,7 @@ void req_register(
      * yet recovered, that is not an error.
      */
 
-    if (server.sv_attr[(int)SRV_ATR_State].at_val.at_long != SV_STATE_INIT)
+    if (server.sv_attr[SRV_ATR_State].at_val.at_long != SV_STATE_INIT)
       {
       log_event(
         PBSEVENT_DEBUG,
@@ -267,7 +267,7 @@ void req_register(
       log_buffer);
     }
 
-  pattr = &pjob->ji_wattr[(int)JOB_ATR_depend];
+  pattr = &pjob->ji_wattr[JOB_ATR_depend];
 
   pjob->ji_modified = 1;
 
@@ -487,10 +487,10 @@ void req_register(
             set_depend_hold(pjob, pattr);
 
             sprintf(tmpcoststr, "%ld", preq->rq_ind.rq_register.rq_cost);
-            pjob->ji_wattr[(int)JOB_ATR_sched_hint].at_val.at_str =
+            pjob->ji_wattr[JOB_ATR_sched_hint].at_val.at_str =
               strdup(tmpcoststr);
 
-            pjob->ji_wattr[(int)JOB_ATR_sched_hint].at_flags |= ATR_VFLAG_SET;
+            pjob->ji_wattr[JOB_ATR_sched_hint].at_flags |= ATR_VFLAG_SET;
             }
           else
             {
@@ -605,7 +605,11 @@ void req_register(
   else
     {
     if ((pjob != NULL) && (pjob->ji_modified != 0))
-      job_save(pjob, SAVEJOB_FULL);
+      {
+
+      job_save(pjob, SAVEJOB_FULL, 0);
+
+      }
 
     reply_ack(preq);
     }
@@ -1135,7 +1139,7 @@ int depend_on_que(
     {
     /* if there are dependencies being removed, unregister them */
 
-    alter_unreg((job *)pjob, &((job *)pjob)->ji_wattr[(int)JOB_ATR_depend], pattr);
+    alter_unreg((job *)pjob, &((job *)pjob)->ji_wattr[JOB_ATR_depend], pattr);
     }
 
   /* First set a System hold if required */
@@ -1207,7 +1211,7 @@ static void post_doe(
 
   if (pjob != NULL)
     {
-    pattr = &pjob->ji_wattr[(int)JOB_ATR_depend];
+    pattr = &pjob->ji_wattr[JOB_ATR_depend];
     pdep  = find_depend(JOB_DEPEND_TYPE_BEFORESTART, pattr);
 
     pdj   = find_dependjob(pdep, preq->rq_ind.rq_register.rq_parent);
@@ -1253,7 +1257,7 @@ int depend_on_exec(
 
   pdep = find_depend(
            JOB_DEPEND_TYPE_BEFORESTART,
-           &pjob->ji_wattr[(int)JOB_ATR_depend]);
+           &pjob->ji_wattr[JOB_ATR_depend]);
 
   if (pdep != NULL)
     {
@@ -1278,7 +1282,7 @@ int depend_on_exec(
 
   pdep = find_depend(
            JOB_DEPEND_TYPE_SYNCWITH,
-           &pjob->ji_wattr[(int)JOB_ATR_depend]);
+           &pjob->ji_wattr[JOB_ATR_depend]);
 
   if (pdep != NULL)
     {
@@ -1299,7 +1303,7 @@ int depend_on_exec(
   /* If I am the master of a sync set, skip the sending (to myself) */
   /* a ready, just cut direct to releasing the next cheapest        */
 
-  pdep = find_depend(JOB_DEPEND_TYPE_SYNCCT, &pjob->ji_wattr[(int)JOB_ATR_depend]);
+  pdep = find_depend(JOB_DEPEND_TYPE_SYNCCT, &pjob->ji_wattr[JOB_ATR_depend]);
 
   if (pdep != NULL)
     {
@@ -1348,7 +1352,7 @@ int depend_on_term(
   int        shouldkill = 0;
   int        type;
 
-  pattr = &pjob->ji_wattr[(int)JOB_ATR_depend];
+  pattr = &pjob->ji_wattr[JOB_ATR_depend];
 
   pdep = (struct depend *)GET_NEXT(pattr->at_val.at_list);
 
@@ -1683,7 +1687,7 @@ void depend_clrrdy(
 
   struct depend_job *pdjb;
 
-  pdp = (struct depend *)GET_NEXT(pjob->ji_wattr[(int)JOB_ATR_depend].at_val.at_list);
+  pdp = (struct depend *)GET_NEXT(pjob->ji_wattr[JOB_ATR_depend].at_val.at_list);
 
   while ((pdp != NULL) && (pdp->dp_type == JOB_DEPEND_TYPE_SYNCCT))
     {
@@ -1960,10 +1964,6 @@ static int unregister_sync(
   return(0);
   }  /* END unregister_sync() */
 
-
-
-
-
 /*
  * find_dependjob - find a child dependent job with a certain job id
  */
@@ -2018,7 +2018,6 @@ static struct depend_job *make_dependjob(
     pdj->dc_cost  = 0;
 
     strcpy(pdj->dc_child, jobid);
-
     if(server_name != NULL)
       strcpy(pdj->dc_svr, server_name);
     else
@@ -2065,7 +2064,7 @@ static int send_depend_req(
   for (i = 0;i < PBS_MAXUSER;++i)
     {
     preq->rq_ind.rq_register.rq_owner[i] =
-      pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str[i];
+      pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str[i];
 
     if (preq->rq_ind.rq_register.rq_owner[i] == '@')
       break;
