@@ -245,8 +245,10 @@ void req_rerunjob(
   if (pjob->ji_qs.ji_state == JOB_STATE_RUNNING)
     {
     /* ask MOM to kill off the job if it is running */
+    static char *rerun = "rerun";
+    char        *extra = strdup(rerun);
 
-    rc = issue_signal(pjob, "SIGKILL", post_rerun, 0);
+    rc = issue_signal(pjob, "SIGKILL", post_rerun, extra);
     }
   else
     { 
@@ -358,6 +360,10 @@ void req_rerunjob(
 
           job_attr_def[JOB_ATR_session_id].at_free(
             &pjob->ji_wattr[JOB_ATR_session_id]);
+
+          job_attr_def[JOB_ATR_exec_gpus].at_free(
+            &pjob->ji_wattr[JOB_ATR_exec_gpus]);
+
           }
 
         pjob->ji_modified = 1;    /* force full job save */
